from typing import Dict

from tablate.type.primitives import Colors

ascii_background_colors: Dict[Colors, str] = {
    "default": "",
    "white": "107",
    "grey": "47",
    "red": "101",
    "green": "102",
    "yellow": "103",
    "blue": "104",
    "magenta": "105",
    "cyan": "106",
    "dark_red": "41",
    "dark_green": "42",
    "dark_yellow": "43",
    "dark_blue": "44",
    "dark_magenta": "45",
    "dark_cyan": "46",
    "dark_grey": "100",
    "black": "40",
}